part of masamune.flutter;

/// Class that manages values for hooks.
///
/// Please use in conjunction with UIWidget.
///
/// Usually used to get the value using [get()] and [text()].
class UIHookValue {
  /// Root observer.
  ///
  /// ```
  /// return new MaterialApp(
  ///   ...
  ///   navigatorObservers: <NavigatorObserver>[UIHookValue.routeObserver],
  ///   ...
  /// );
  /// ```
  final _UIHookWidgetState _state;

  /// List of Paths to dispose with when UIValue is disposed.
  final PathList willDisposePathList = PathList();
  UIHookValue._(_UIHookWidgetState state) : this._state = state;

  /// The closest instance of this class that encloses the given context.
  ///
  /// Typical usage:
  ///
  /// ```dart
  /// UIValue controller = UIValue.of(context);
  /// ```
  ///
  /// [context]: Build context.
  static UIHookValue of(BuildContext context) {
    final _UIHookWidgetScope scope = context
        .getElementForInheritedWidgetOfExactType<_UIHookWidgetScope>()
        ?.widget;
    return scope?.target?._value;
  }

  /// Forces the widget to update.
  void refresh() => this._state?._refresh();

  void _dispose() {
    this.willDisposePathList.dispose();
  }
}
